@@ -168,7 +168,7 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
         additional_page_context_kwargs = self.dynamic_contexts_kwargs[self.context_rotation_idx]
         for key in additional_page_context_kwargs:
             page_context_kwargs[key] = additional_page_context_kwargs[key]
-        page = await self.browser.new_page(page_context_kwargs)
+        page = await self.browser.new_page(**page_context_kwargs)
         # await stealth_async(page)
         self.stats.inc_value("playwright/page_count")
         logger.debug(
