@@ -30,35 +30,24 @@ const parseInput = arg => {
 
 const canPlayType = {
     // Intercept certain requests
-    apply: function (target, ctx, args) {
+    apply: function(target, ctx, args) {
         if (!args || !args.length) {
             return target.apply(ctx, args)
         }
-        const {mime, codecs} = parseInput(args[0])
-        if (mime === 'audio/ogg') {
-            return ''
-        }
+        const { mime, codecs } = parseInput(args[0])
         // This specific mp4 codec is missing in Chromium
-        if (mime === 'audio/mpeg') {
-            return 'maybe'
-        }
-        if (mime === 'audio/wav') {
-            return ''
+        if (mime === 'video/mp4') {
+            if (codecs.includes('avc1.42E01E')) {
+                return 'probably'
+            }
         }
+        // This mimetype is only supported if no codecs are specified
         if (mime === 'audio/x-m4a' && !codecs.length) {
             return 'maybe'
         }
-        if (mime === 'audio/aac' && !codecs.length) {
-            return 'maybe'
-        }
 
-        if (mime === 'video/ogg') {
-            return ''
-        }
-        if (mime === 'video/webm') {
-            return ''
-        }
-        if (mime === 'video/mpeg') {
+        // This mimetype is only supported if no codecs are specified
+        if (mime === 'audio/aac' && !codecs.length) {
             return 'probably'
         }
         // Everything else as usual
