@@ -67,17 +67,26 @@ if (!(hasPlugins)) {
     // Plugin and MimeType cross-reference each other, let's do that now
     // Note: We're looping through `data.plugins` here, not the generated `plugins`
     for (const pluginData of data.plugins) {
-        pluginData.__mimeTypes.forEach((type, index) => {
+          pluginData.__mimeTypes.forEach((type, index) => {
             plugins[pluginData.name][index] = mimeTypes[type]
-            plugins[type] = mimeTypes[type]
-            Object.defineProperty(mimeTypes[type], 'enabledPlugin', {
-                value: JSON.parse(JSON.stringify(plugins[pluginData.name])),
-                writable: false,
-                enumerable: false, // Important: `JSON.stringify(navigator.plugins)`
-                configurable: false
+
+            Object.defineProperty(plugins[pluginData.name], type, {
+              value: mimeTypes[type],
+              writable: false,
+              enumerable: false, // Not enumerable
+              configurable: true
             })
-        })
-    }
+            Object.defineProperty(mimeTypes[type], 'enabledPlugin', {
+              value:
+                type === 'application/x-pnacl'
+                  ? mimeTypes['application/x-nacl'].enabledPlugin // these reference the same plugin, so we need to re-use the Proxy in order to avoid leaks
+                  : new Proxy(plugins[pluginData.name], {}), // Prevent circular references
+              writable: false,
+              enumerable: false, // Important: `JSON.stringify(navigator.plugins)`
+              configurable: true
+            })
+          })
+        }
 
     const patchNavigator = (name, value) =>
         utils.replaceProperty(Object.getPrototypeOf(navigator), name, {
