@@ -1,14 +1,13 @@
-console.log(opts)
 const getParameterProxyHandler = {
     apply: function (target, ctx, args) {
         const param = (args || [])[0]
         // UNMASKED_VENDOR_WEBGL
         if (param === 37445) {
-            return 'Apple Inc.'
+            return opts.webgl_vendor || 'Intel Inc.'
         }
         // UNMASKED_RENDERER_WEBGL
         if (param === 37446) {
-            return 'Apple GPU'
+            return opts.webgl_renderer || 'Intel Iris OpenGL Engine'
         }
         return utils.cache.Reflect.apply(target, ctx, args)
     }
